@@ -128,8 +128,11 @@ pygdk_add_extra_constants(PyObject *m)
 {
     gchar * aname;
 
+    PyModule_AddObject(m, "CURRENT_TIME",
+		       PyLong_FromLong(GDK_CURRENT_TIME));
     PyModule_AddObject(m, "PARENT_RELATIVE",
 		       PyLong_FromLong(GDK_PARENT_RELATIVE));
+
       /* Add predefined atoms */
 #define add_atom(name) { aname = gdk_atom_name((GDK_##name)); \
 PyModule_AddObject(m, #name, PyString_FromString(aname)); \
